@@ -1,3 +1,23 @@
+/**********************************************************************
+This file is part of Exact.
+
+Copyright (c) 2022 Jo Devriendt
+
+Exact is free software: you can redistribute it and/or modify it under
+the terms of the GNU Affero General Public License version 3 as
+published by the Free Software Foundation.
+
+Exact is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public
+License version 3 for more details.
+
+You should have received a copy of the GNU Affero General Public
+License version 3 along with Exact. See the file used_licenses/COPYING
+or run with the flag --license=AGPLv3. If not, see
+<https://www.gnu.org/licenses/>.
+**********************************************************************/
+
 /**********************************************************************
 This file is part of the Exact program
 
@@ -86,7 +106,7 @@ class ILP {
 
   int maxSatVars = -1;
 
-  std::vector<Lit> assumptions;
+  std::vector<Lit> assumptions;  // TODO: pass assumptions to run() instead of keeping track of them here?
 
  public:
   ILP();
@@ -109,6 +129,7 @@ class ILP {
 
   void init(bool boundObjective, bool addNonImplieds);
   SolveState run();
+  SolveState runFull();
 
   State addConstraint(const std::vector<bigint>& coefs, const std::vector<IntVar*>& vars,
                       const std::vector<bool>& negated, const std::optional<bigint>& lb = std::nullopt,
@@ -123,13 +144,15 @@ class ILP {
   ratio getUpperBound() const;
 
   bool hasSolution() const;
-  std::vector<long long> getLastSolutionFor(const std::vector<std::string>& vars) const;
+  std::vector<bigint> getLastSolutionFor(const std::vector<std::string>& vars) const;
 
   bool hasCore() const;
   std::vector<std::string> getLastCore() const;
 
   void printOrigSol() const;
   void printFormula();
+
+  std::vector<std::pair<bigint, bigint>> propagate(const std::vector<std::string>& varnames);
 };
 std::ostream& operator<<(std::ostream& o, const ILP& x);
 
