@@ -1,3 +1,23 @@
+/**********************************************************************
+This file is part of Exact.
+
+Copyright (c) 2022 Jo Devriendt
+
+Exact is free software: you can redistribute it and/or modify it under
+the terms of the GNU Affero General Public License version 3 as
+published by the Free Software Foundation.
+
+Exact is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public
+License version 3 for more details.
+
+You should have received a copy of the GNU Affero General Public
+License version 3 along with Exact. See the file used_licenses/COPYING
+or run with the flag --license=AGPLv3. If not, see
+<https://www.gnu.org/licenses/>.
+**********************************************************************/
+
 /**********************************************************************
 This file is part of the Exact program
 
@@ -77,14 +97,14 @@ class Solver {
 
  public:
   std::vector<Lit> lastSol = {0};
-  bool foundSolution() const { return getNbOrigVars() == 0 || lastSol.size() > 1; }
+  bool foundSolution() const { return stats.NORIGVARS.z == 0 || lastSol.size() > 1; }
   CeSuper lastCore;
   IntSet objectiveLits;
 
  private:
   ILP& ilp;
   int n;
-  int orig_n;
+  std::vector<bool> isorig;
 
   ConstraintAllocator ca;
   Heuristic freeHeur;
@@ -126,7 +146,10 @@ class Solver {
 
   int getNbVars() const { return n; }
   void setNbVars(int nvars, bool orig);
-  int getNbOrigVars() const { return orig_n; }
+  bool isOrig(Var v) const {
+    assert(v > 0);
+    return isorig[v];
+  }
 
   const IntMap<int>& getLevel() const { return level; }
   const std::vector<int>& getPos() const { return position; }
