@@ -1,3 +1,23 @@
+/**********************************************************************
+This file is part of Exact.
+
+Copyright (c) 2022 Jo Devriendt
+
+Exact is free software: you can redistribute it and/or modify it under
+the terms of the GNU Affero General Public License version 3 as
+published by the Free Software Foundation.
+
+Exact is distributed in the hope that it will be useful, but WITHOUT
+ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero General Public
+License version 3 for more details.
+
+You should have received a copy of the GNU Affero General Public
+License version 3 along with Exact. See the file used_licenses/COPYING
+or run with the flag --license=AGPLv3. If not, see
+<https://www.gnu.org/licenses/>.
+**********************************************************************/
+
 /**********************************************************************
 This file is part of the Exact program
 
@@ -41,7 +61,7 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #pragma once
 
-#include "aux.hpp"
+#include "auxiliary.hpp"
 #include "typedefs.hpp"
 
 namespace xct {
@@ -196,7 +216,6 @@ struct Stats {
   Stat ATMOSTONEDETTIME{0, "at-most-one detection time det"};
   Stat NATMOSTONEUNITS{0, "units derived during at-most-one detection"};
 
-  Stat STARTTIME{0, "start time"};
   Stat PARSETIME{0, "parse time"};
   Stat SOLVETIMEFREE{0, "free solve time"};
   Stat DETTIMEFREE{0, "free solve time det"};
@@ -205,7 +224,6 @@ struct Stats {
   Stat CATIME{0, "conflict analysis time"};
   Stat MINTIME{0, "learned minimize time"};
   Stat PROPTIME{0, "propagation time"};
-  Stat RUNSTARTTIME{0, "solve start time"};
   Stat TABUTIME{0, "local search time"};
   Stat TABUDETTIME{0, "local search time det"};
 
@@ -298,6 +316,9 @@ struct Stats {
   Stat TABUFLIPS{0, "number of local search literal flips"};
   Stat NTABUUNITS{0, "units derived during local search"};
 
+  std::chrono::steady_clock::time_point startTime;
+  std::chrono::steady_clock::time_point runStartTime;
+
   void setDerivedStats() {
     DETTIME.z = getDetTime();
     CPUTIME.z = getTime();
@@ -441,8 +462,14 @@ struct Stats {
       &NTABUUNITS,
   };
 
-  [[nodiscard]] inline long double getTime() const { return aux::cpuTime() - STARTTIME; }
-  [[nodiscard]] inline long double getRunTime() const { return aux::cpuTime() - RUNSTARTTIME; }
+  [[nodiscard]] inline long double getTime() const {
+    return std::chrono::duration_cast<std::chrono::duration<double>>(std::chrono::steady_clock::now() - startTime)
+        .count();
+  }
+  [[nodiscard]] inline long double getRunTime() const {
+    return std::chrono::duration_cast<std::chrono::duration<double>>(std::chrono::steady_clock::now() - runStartTime)
+        .count();
+  }
   [[nodiscard]] inline long double getSolveTime() const { return SOLVETIMEFREE + SOLVETIMEASSUMP; }
   // NOTE: below linear relations were determined by regression tests on experimental data,
   // so that the deterministic time correlates as closely as possible with the cpu time in seconds
